#
# spec file for package xrefresh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xrefresh
Version:        1.1.0
Release:        1.5
Summary:        Utility to refresh all or part of an X screen
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz.sig
Source2:        xrefresh.keyring
Source3:        xrefresh.desktop
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
Xrefresh is a simple X program that causes all or part of your screen
to be repainted. This is useful when system messages have messed up
your screen.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -i -u xrefresh Utility DesktopUtility

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xrefresh
%{_datadir}/applications/xrefresh.desktop
%{_mandir}/man1/xrefresh.1%{?ext_man}

%changelog
* Mon Mar  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.8
  * gitlab CI: stop requiring Signed-off-by in commits
  * Add -help option
  * Adding in a '-delay ms' parameter to optionally prolong refreshx
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- modernize spec-file, move license to licensedir
- use gpg validation for sources
* Tue Jul 12 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.7
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * xrefresh.man: In 2019, few monitors have electron guns in tubes
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.0.6
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Tue May 21 2013 zaitor@opensuse.org
- Update to version 1.0.5:
  + Use strcasecmp if available, instead of downcasing string
    before strcmp.
  + Fix implicit sign conversion & integer size truncation
    warnings.
  + Combine usage message strings.
  + Mark Syntax() with _X_NORETURN to silence gcc warning.
  + Add const qualifiers to structs for mapping strings to values.
  + Add const qualifiers to fix gcc -Wwrite-strings warnings.
  + Properly fallback on CWBackPixmap = None when failing to parse
    or allocate a solid color.
  + Fix allocateded typo in comment.
  + config: move man pages into their own directory.
  + man: remove trailing spaces and tabs.
- Add pkgconfig(xproto) BuildRequires: configure now checks for it.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xrefresh from xorg-x11. Initial version: 1.0.4.
